@@ -937,10 +937,8 @@ class Jp2k(Jp2kBox):
         elif opj.OPENJPEG is not None:
             img = self._read_openjpeg(**kwargs)
         else:
-            raise LibraryNotFoundError("You must have either a recent version "
-                                       "of OpenJPEG or the development "
-                                       "version of OpenJP2 installed before "
-                                       "using this functionality.")
+            raise LibraryNotFoundError("You must have OpenJPEG installed "
+                                       "before reading a JPEG2000 image.") 
         return img
 
     def _subsampling_sanity_check(self):
@@ -1235,8 +1233,8 @@ class Jp2k(Jp2kBox):
         """
         if version.openjpeg_version_tuple[0] < 2:
             raise LibraryNotFoundError("You must have at least version 2.0.0 "
-                                       "of OpenJP2 installed before using "
-                                       "this functionality.")
+                                       "of OpenJPEG installed before using "
+                                       "read_bands.")
 
         dparam = self._populate_dparam(rlevel, ignore_pclr_cmap_cdef,
                                        layer=layer, tile=tile, area=area)
