@@ -5,15 +5,11 @@ Test suite for codestream parsing.
 # unittest doesn't work well with R0904.
 # pylint: disable=R0904
 
-# tempfile.TemporaryDirectory, unittest.assertWarns introduced in 3.2
-# pylint: disable=E1101
-
 import os
 import struct
 import sys
 import tempfile
 import unittest
-import warnings
 
 from glymur import Jp2k
 import glymur
